@@ -17,7 +17,7 @@ class RoyaltyModuleClient:
                 break
         if not contract_address:
             raise ValueError(f"Contract address for RoyaltyModule not found in config.json")
-        abi_path = os.path.join(os.path.dirname(__file__), 'RoyaltyModule.json')
+        abi_path = os.path.join(os.path.dirname(__file__), '..', '..', 'abi', 'jsons', 'RoyaltyModule.json')
         with open(abi_path, 'r') as abi_file:
             abi = json.load(abi_file)
         self.contract = self.web3.eth.contract(address=contract_address, abi=abi)
@@ -29,4 +29,14 @@ class RoyaltyModuleClient:
     def build_payRoyaltyOnBehalf_transaction(self, receiverIpId, payerIpId, token, amount, tx_params):
         return self.contract.functions.payRoyaltyOnBehalf(receiverIpId, payerIpId, token, amount).build_transaction(tx_params)
     
+    
+    def isWhitelistedRoyaltyPolicy(self, royaltyPolicy):
+        
+        return self.contract.functions.isWhitelistedRoyaltyPolicy(royaltyPolicy).call()
+        
+    
+    def isWhitelistedRoyaltyToken(self, token):
+        
+        return self.contract.functions.isWhitelistedRoyaltyToken(token).call()
+        
     
\ No newline at end of file
